#!/bin/bash

#
# Converts all tracks in Assets/tracks-java into Assets/tracks,
# then creates TrackData.msm with all tracks and replays from
# Assets/tracks.
#
# TrackData.msm will only be updated if needed, and it works
# both when tracks are added and deleted.
# Note: Tracks must both be deleted from Assets/tracks and 
# Assets/track-java.
#

if [ "${ACTION}" = "clean" ]
then
	echo "PackTrackReplays: Ignores xcode clean."
	exit 0
fi

dirInput="${SRCROOT}/Converts/Input"
dirOutput="${SRCROOT}/Converts/Output"
convertJar="${SRCROOT}/utils/trackConvert.jar"


mkdir -p $dirInput
mkdir -p $dirOutput

# Delete converted tracks where thes source file has been deleted
for pathname in $dirOutput/*.itrack
do
	filename=$(basename "$pathname")
	name=${filename%.itrack}
	srcFile="$dirInput/$name.msmtrack"
	# If the source file no longer exists we delete the old destination file
	if [ ! -e "$srcFile" ];
	then
		echo "Delete $filename"
		rm -f "$pathname"
		touch -cm "$tracksDir"
	fi
done

# Convert tracks from Java to iPhone
for pathname in $dirInput/*.*
do
	filename=$(basename "$pathname")
	path=$(dirname "$pathname")
	name=${filename%.msmtrack}	
	destName="$name.itrack"
	destFile="$dirOutput/$destName"

	# True if file1 is older than file2,
	# or if file2 exists but file1 doesn't.
	if [ "$destFile" -ot "$pathname" ]
	then
		echo "Convert $filename..."
		java -jar $convertJar -file "$pathname" "$dirOutput"
	else
		echo "" #"$destName is up to date"
	fi
done


echo "Done"
exit 0