var GameRequest = new Class({
	initialize: function(path, onSuccessCallback, onFailureCallback, onTimeoutCallback) {
		var requestUrl = config.serverUrl + path;
		var gameRequest = this;
		this.request = new Request({
			url : requestUrl,
			method : 'post',
			async : true,
			timeout : requestTimeout,
			onTimeout : function() {
				console.log(path + ' timed out!');
				try {
					if (isFunction(onTimeoutCallback))
						onTimeoutCallback();
					else 
						globalOnTimeout(requestUrl);
				} catch (e) { handle(e); }
			},
			onRequest : function() {
				console.log('request ' + requestUrl);				
			},
			onSuccess : function(responseText) {
				console.log('response ' + requestUrl);
				var responseJSON = null;
				try {
					responseJSON = JSON.decode(responseText);
				} catch (e) {
					console.log(requestUrl + ' invalid json: ' + responseText);
					try {
						if (isFunction(onFailureCallback))
							onFailureCallback();
					} catch (e) { handle(e); }
					return;
				}
				if (responseJSON.result == 'SUCCESS') {
					console.log('json: ' + responseText);
					try {
						if (isFunction(onSuccessCallback))
							onSuccessCallback(responseJSON);
					} catch (e) { handle(e); }
				} else {
					if (responseJSON.result == 'WRONG_VERSION') {
						console.log('Wrong version. My version '+config.version+'. Server version '+responseJSON.serverVersion);
						gameRequest.handleWrongVersion(responseJSON.serverVersion);
						// No failure response. Just stop the program.
					} else {
						console.log('request ' + path + ' returned error: '+responseJSON.errorMessage);
						console.log('json: ' + responseText);
						
						if (responseJSON.result == 'USER_MESSAGE')
							alert(responseJSON.errorMessage);
						
						try {
							if (isFunction(onFailureCallback))
								onFailureCallback(responseJSON);
						} catch (e) { handle(e); }

					}			
				}
			},
			onFailure : function(xhr) {
				console.log(requestUrl + ' failed', xhr);
				try {
					if (isFunction(onFailureCallback))
						onFailureCallback();
				} catch (e) { handle(e); }
			},
			onException : function(headerName, value) {
				console.log(requestUrl + ' exception: ' + headerName + ' + ' + value);
				try {
					if (isFunction(onFailureCallback))
						onFailureCallback();
				} catch (e) { handle(e); }
			},
			onError: function(text, error) {
				console.log(requestUrl + ' json error=' + error + ' text=' + text);
				try {
					if (isFunction(onFailureCallback))
						onFailureCallback();
				} catch (e) { handle(e); }
			}
		});	
	},
	send: function(data) {
		if (GameRequest.stopped)
			return;
		var json = {
			version: config.version,
			game: config.game,
			platform: config.platform,
			userId: user.id,
			password: user.password,
			data: data
		};
		var encoded = JSON.encode(json);
		this.request.post('json=' + encoded);
		console.log('Requesting: json=' + encoded);
	},
	handleWrongVersion: function(newVersion) {
		GameRequest.stopped = true;
	}
});