/**
 * 
 * Usage example:
 * 
 * var username = 'Peter Sundqvist';
 * var userId = '123';
 * var facebookId = '1321307561';
 * var score = 1234;
 * var mayRetryConnection = false;
 *	
 * var highscores = new Array(
 *    new Highscore(facebookId, userId, username, score)
 * );
 *	
 * showOfflineLeaderboard('bmx-test-level', 'Time Attack', highscores, mayRetryConnection);
 * 
 * Notes: 
 * 
 * - The facebookId and userId can be null. If the facebook id is null we 
 *   show the no-face picture, otherwise we try to load a picture from cache.
 * 
 * - The watch and attack buttons will be disabled for all highscores, 
 *   except the one with our own user id.
 * 
 * @param board The id of the leaderboard
 * @param boardName The title of the leaderboard
 * @param highscores An array with the Highscore's to show
 * @param mayRetryConnection The retry connection button is shown if 
 *        this is true, and the facebook login button is shown if it's false.
 */
function showOfflineLeaderboard(board, boardName, highscores, mayRetryConnection) {
	config.userMayRetryConnection = mayRetryConnection;
	
	display(function() {  
		var leaderboard = getFriendLeaderboardInstance(board, boardName);
		leaderboard.updateWithHighscores(highscores, null);			
		return leaderboard;
	});
}

/**
 * Show the retry connection button or the loading spinner in its place.
 * @param state Set to 'loading' or 'button' to display either the loading spinner or the retry button.
 */
function setRetryConnectionButton(state) {
	var loader = $('retry_connection_loader');
	var button = $('retry_connection_button');
	
	if (!loader || !button) {
		console.error('Retry connection button doesn\'t exist.');
		return;
	}
	
	if (loaderTimeout !== null) {
		clearTimeout(loaderTimeout);
		loaderTimeOut = null;
	}
	if (state == 'loading') {
		loader.setStyle('display','block');
		button.setStyle('display','none');
	} else if (state == 'button') {
		loaderTimeout = setTimeout(function () {
			loader.setStyle('display','none');
			button.setStyle('display','block');
		}, 400);
	}
}

var loaderTimeout = null;